==> nextcloud-26.0.13.zip: nextcloud/apps/viewer/l10n/sk.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Prehliadač",
    "Simple file viewer with slideshow for media" : "Jednoduchý prehliadač súborov s režimom prezentácie pre obrázky a iné médiá",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Prezentujte vaše fotky a videá z dovolenky ako film, ukážte časti vášho posledného zážitku priamo z vášho Nextcloudu. Vyberte najlepšiu GIF animáciu z vašej zbierky vďaka okamžitému náhľadu vašich obľúbených súborov a ešte oveľa viac!",
    "Your browser does not support audio." : "Váš prehliadač nepodporuje zvuk.",
    "Error loading {name}" : "Nepodarilo sa zobraziť {name}",
    "Image saved" : "Obrázok uložený",
    "Error saving image" : "Chyba pri ukladaní obrázku",
    "Unsaved changes" : "Neuložené zmeny",
    "Drop changes" : "Zrušiť zmeny",
    "LIVE" : "ŽIVÉ",
    "Your browser does not support videos." : "Váš prehliadač nepodporuje videá.",
    "Edit" : "Upraviť",
    "Exit full screen" : "Ukončiť režim celej obrazovky",
    "Full screen" : "Celá obrazovka",
    "Open sidebar" : "Otvoriť bočný panel",
    "Download" : "Stiahnuť",
    "Delete" : "Zmazať",
    "There is no plugin available to display this file type" : "Pre zobrazenie tohto typu súboru nie je k dispozícii žiadny doplnok",
    "View" : "Prezerať",
    "Name" : "Meno",
    "Save" : "Uložiť",
    "Save as" : "Uložiť ako",
    "Back" : "Späť",
    "Loading …" : "Načítavam …",
    "Reset" : "Resetovať",
    "All changes will be lost." : "Vaše zmeny budú stratené.",
    "Are you sure you want to continue?" : "Naozaj chcete pokračovať?",
    "Cancel" : "Zrušiť",
    "Continue" : "Pokračovať",
    "Undo" : "Vrátiť",
    "Redo" : "Vrátiť",
    "Show original image" : "Zobraziť originálny obrázok",
    "Zoom in" : "Priblížiť",
    "Zoom out" : "Oddialiť",
    "Toggle zoom menu" : "Prepnúť ponuku priblíženia",
    "Adjust" : "Prispôsobiť",
    "Fine-tune" : "Vylepšiť",
    "Filters" : "Filtre",
    "Watermark" : "Vodoznak",
    "Draw" : "Kreslenie",
    "Resize" : "Zmeniť veľkosť",
    "Invalid image." : "Chybný obrázok.",
    "Error while uploading the image." : "Chyba pri nahrávaní obrázku",
    "are not images" : "nie sú obrázky",
    "is not an image" : "nie je obrázok",
    "to be uploaded" : "bude nahrané",
    "Crop" : "Orezať",
    "Original" : "Pôvodné",
    "Custom" : "Vlastný",
    "Square" : "Štvorec",
    "Landscape" : "Na šírku",
    "Portrait" : "Na výšku",
    "Ellipse" : "Elipsa",
    "Classic TV" : "Klasická TV",
    "CinemaScope" : "Širokoúhlo",
    "Arrow" : "Šípka",
    "Blur" : "Rozmazať",
    "Brightness" : "Jas",
    "Contrast" : "Kontrast",
    "Un-flip X" : "Vrátiť prevrátenie zvislo",
    "Flip X" : "Prevrátiť zvislo",
    "Un-flip Y" : "Vrátiť prevrátenie vodorovne",
    "Flip Y" : "Prevrátiť vodorovne",
    "HSV" : "HSV",
    "Hue" : "Odtieň",
    "Saturation" : "Sýtosť",
    "Value" : "Hodnota",
    "Image" : "Obrázok",
    "Importing …" : "Importuje sa ...",
    "+ Add image" : "+ Pridať obrázok",
    "Line" : "Čiara",
    "Pen" : "Pero",
    "Polygon" : "Mnohouholník",
    "Sides" : "Strany",
    "Rectangle" : "Odĺžnik",
    "Corner Radius" : "Polomer zaoblenia",
    "Width in pixels" : "Šírka v pixeloch",
    "Height in pixels" : "Výška v pixeloch",
    "Toggle ratio lock" : "Prepnúť zámok pomeru strán",
    "Reset to original image size" : "Vrátiť pôvodnú veľkost obrázku",
    "Rotate" : "Otočiť",
    "Text" : "Text",
    "Text spacing" : "Riadkovanie",
    "Text alignment" : "Zarovnanie textu",
    "Font family" : "Typ písma",
    "Size" : "Veľkosť",
    "Letter spacing" : "Medzery medzi písmenami",
    "Line height" : "Hrúbka čiary",
    "Warmth" : "Teplota",
    "+ Add watermark" : "+ Pridať vodoznak",
    "Choose watermark type" : "Vyberte typ vodoznaku",
    "Upload watermark" : "Nahrať vodoznak",
    "Add as text" : "Pridať ako text",
    "Padding" : "Okraj",
    "Shadow" : "Tieň",
    "Horizontal" : "Horizontálne",
    "Vertical" : "Vertikálne",
    "Opacity" : "Priehľadnosť",
    "Position" : "Pozícia",
    "Stroke" : "Potiahnuť",
    "Save image as" : "Uložiť obrázok ako",
    "Extension" : "Prípona",
    "Name is required." : "Meno je povinné.",
    "Quality" : "Kvalita",
    "Saved image size (width x height)" : "Veľkosť uloženého obrázka (šírka x výška)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Upozorňujeme, že vybratá oblasť orezania je menšia ako použitá zmena veľkosti, čo môže spôsobiť zníženie kvality",
    "Actual size (100%)" : "Aktuálna veľkosť (100%)",
    "Fit size" : "Prispôsobiť veľlkosť"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-28.0.14rc1.zip: nextcloud/apps/viewer/l10n/sk.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Prehliadač",
    "Simple file viewer with slideshow for media" : "Jednoduchý prehliadač súborov s režimom prezentácie pre obrázky a iné médiá",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Prezentujte vaše fotky a videá z dovolenky ako film, ukážte časti vášho posledného zážitku priamo z vášho Nextcloudu. Vyberte najlepšiu GIF animáciu z vašej zbierky vďaka okamžitému náhľadu vašich obľúbených súborov a ešte oveľa viac!",
    "Your browser does not support audio." : "Váš prehliadač nepodporuje zvuk.",
    "Error loading {name}" : "Nepodarilo sa zobraziť {name}",
    "Image saved" : "Obrázok uložený",
    "Error saving image" : "Chyba pri ukladaní obrázku",
    "Unsaved changes" : "Neuložené zmeny",
    "Drop changes" : "Zrušiť zmeny",
    "Play the live photo" : "Prehrajte aktívnu fotografiu",
    "LIVE" : "NA ŽIVO",
    "Your browser does not support videos." : "Váš prehliadač nepodporuje videá.",
    "Edit" : "Upraviť",
    "Exit full screen" : "Ukončiť režim celej obrazovky",
    "Full screen" : "Celá obrazovka",
    "Open sidebar" : "Otvoriť bočný panel",
    "Download" : "Stiahnuť",
    "Delete" : "Zmazať",
    "This file no longer exists" : "Tento súbor už neexistuje",
    "There is no plugin available to display this file type" : "Pre zobrazenie tohto typu súboru nie je k dispozícii žiadny doplnok",
    "View" : "Prezerať",
    "Name" : "Meno",
    "Save" : "Uložiť",
    "Save as" : "Uložiť ako",
    "Back" : "Späť",
    "Loading …" : "Načítavam …",
    "Reset" : "Resetovať/Obnoviť",
    "All changes will be lost." : "Všetky zmeny sa stratia.",
    "Are you sure you want to continue?" : "Naozaj chcete pokračovať?",
    "Cancel" : "Zrušiť",
    "Apply" : "Použiť",
    "Warning" : "Varovanie",
    "Confirm" : "Potvrdiť",
    "Discard changes" : "Zahodiť zmeny",
    "Undo" : "Vrátiť",
    "Redo" : "Prerobiť",
    "Show original image" : "Zobraziť pôvodný obrázok",
    "Zoom in" : "Priblížiť",
    "Zoom out" : "Oddialiť",
    "Toggle zoom menu" : "Prepnúť ponuku priblíženia",
    "Adjust" : "Prispôsobiť",
    "Fine-tune" : "Vylepšiť",
    "Filters" : "Filtre",
    "Watermark" : "Vodoznak",
    "Draw" : "Kreslenie",
    "Resize" : "Zmeniť veľkosť",
    "Invalid image." : "Chybný obrázok.",
    "Error while uploading the image." : "Chyba pri nahrávaní obrázku",
    "are not images" : "nie sú obrázky",
    "is not an image" : "nie je obrázok",
    "to be uploaded" : "bude nahrané",
    "Crop" : "Orezať",
    "Original" : "Pôvodné",
    "Custom" : "Vlastný",
    "Square" : "Štvorec",
    "Landscape" : "Na šírku",
    "Portrait" : "Na výšku",
    "Ellipse" : "Elipsa",
    "Classic TV" : "Klasická TV",
    "CinemaScope" : "Širokoúhlo",
    "Arrow" : "Šípka",
    "Blur" : "Rozmazať",
    "Brightness" : "Jas",
    "Contrast" : "Kontrast",
    "Un-flip X" : "Vrátiť prevrátenie zvislo",
    "Flip X" : "Prevrátiť zvislo",
    "Un-flip Y" : "Vrátiť prevrátenie vodorovne",
    "Flip Y" : "Prevrátiť vodorovne",
    "HSV" : "HSV",
    "Hue" : "Odtieň",
    "Saturation" : "Sýtosť",
    "Value" : "Hodnota",
    "Image" : "Obrázok",
    "Importing …" : "Importuje sa ...",
    "+ Add image" : "+ Pridať obrázok",
    "Line" : "Čiara",
    "Pen" : "Pero",
    "Polygon" : "Mnohouholník",
    "Sides" : "Strany",
    "Rectangle" : "Odĺžnik",
    "Corner Radius" : "Polomer zaoblenia",
    "Width in pixels" : "Šírka v pixeloch",
    "Height in pixels" : "Výška v pixeloch",
    "Toggle ratio lock" : "Prepnúť zámok pomeru strán",
    "Reset to original image size" : "Vrátiť pôvodnú veľkost obrázku",
    "Rotate" : "Otočiť",
    "Text" : "Text",
    "Text spacing" : "Riadkovanie",
    "Text alignment" : "Zarovnanie textu",
    "Font family" : "Typ písma",
    "Size" : "Veľkosť",
    "Letter spacing" : "Medzery medzi písmenami",
    "Line height" : "Hrúbka čiary",
    "Warmth" : "Teplota",
    "+ Add watermark" : "+ Pridať vodoznak",
    "Choose watermark type" : "Vyberte typ vodoznaku",
    "Upload watermark" : "Nahrať vodoznak",
    "Add as text" : "Pridať ako text",
    "Padding" : "Okraj",
    "Shadow" : "Tieň",
    "Horizontal" : "Horizontálne",
    "Vertical" : "Vertikálne",
    "Opacity" : "Priehľadnosť",
    "Position" : "Pozícia",
    "Stroke" : "Potiahnuť",
    "Save image as" : "Uložiť obrázok ako",
    "Extension" : "Prípona",
    "Name is required." : "Meno je povinné.",
    "Quality" : "Kvalita",
    "Saved image size (width x height)" : "Veľkosť uloženého obrázka (šírka x výška)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Upozorňujeme, že vybratá oblasť orezania je menšia ako použitá zmena veľkosti, čo môže spôsobiť zníženie kvality",
    "Actual size (100%)" : "Aktuálna veľkosť (100%)",
    "Fit size" : "Prispôsobiť veľlkosť",
    "Menu" : "Menu",
    "Height" : "Výška"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
